utils

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrProjShootUIDInvalidFormat = errors.New("input not in the correct format: projectName--shootUID")

ErrProjShootUIDInvalidFormat is an error that is returned if an issuer metadata shoot secret name is not in the correct format.

Functions

func LoadKeySet added in v0.2.0

func LoadKeySet(jwks []byte) (*jose.JSONWebKeySet, error)

LoadKeySet parses the jwks key set.

func SplitProjectNameAndShootUID

func SplitProjectNameAndShootUID(key string) (string, string, error)

SplitProjectNameAndShootUID splits the key by '--' in two parts.

Types

type OpenIDMetadata added in v0.2.0

type OpenIDMetadata struct {
	Issuer  string `json:"issuer"`
	JWKSURI string `json:"jwks_uri"`
}

OpenIDMetadata is a minimal struct allowing to parse the issuer and jwks URIs from the OIDC discovery page.

func LoadOpenIDConfig added in v0.2.0

func LoadOpenIDConfig(config []byte) (*OpenIDMetadata, error)

LoadOpenIDConfig parses the openid configuration page.

Jump to