Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrProjShootUIDInvalidFormat = errors.New("input not in the correct format: projectName--shootUID")
ErrProjShootUIDInvalidFormat is an error that is returned if an issuer metadata shoot secret name is not in the correct format.
Functions ¶
func LoadKeySet ¶ added in v0.2.0
func LoadKeySet(jwks []byte) (*jose.JSONWebKeySet, error)
LoadKeySet parses the jwks key set.
Types ¶
type OpenIDMetadata ¶ added in v0.2.0
OpenIDMetadata is a minimal struct allowing to parse the issuer and jwks URIs from the OIDC discovery page.
func LoadOpenIDConfig ¶ added in v0.2.0
func LoadOpenIDConfig(config []byte) (*OpenIDMetadata, error)
LoadOpenIDConfig parses the openid configuration page.
Click to show internal directories.
Click to hide internal directories.